==> txdpy-8.9.5-py3-none-any.whl: txdpy/__init__.py <==
__all__ = ['prurar_code', 'convert_pc', 'convert_kl', 'delete_flase_empty', 'txdavg', 'txdpercavg', 'txdmin', 'txdperc',
           'QueryScoreRank', 'timer', 'exenla', 'getexcelth', 'ExtractEnrollmentLabels', 'UpdateName', 'sortedlbys',
           'GetSchoolNameBz', 'GetMajorNameBz', 'unify_keys', 'school_ljdm', 'prvadepl', 'optstr', 'MysqlConn',
           'read_excel', 'ReadData', 'gen_excel', 'liduel', 'list_dupl', 'get_chinese', 'get_letter', 'get_bletter',
           'get_sletter', 'get_num', 'get_num_letter', 'is_num', 'is_sletter',
           'is_bletter', 'is_letter', 'is_num_letter', 'is_chinese', 'PyMySQL', '文本括号及引号不匹配检查', 'req',
           'format_string_dict', 'webptablesl', 'dow_file', 'TextSimilar', 'translate', '文本错别字检查方法二',
           'get_ssq', 'is_ssq', 'is_school', 'get_major_name', 'school_names', 'major_names'
           ]

from .bk_179 import prurar_code
from .bk_179 import convert_pc
from .bk_179 import convert_kl
from .bk_179 import delete_flase_empty
from .bk_179 import txdavg
from .bk_179 import txdpercavg
from .bk_179 import txdmin
from .bk_179 import txdperc
from .bk_179 import QueryScoreRank
from .bk_179 import timer
from .bk_179 import exenla
from .bk_179 import getexcelth
from .bk_179 import ExtractEnrollmentLabels
from .bk_179 import UpdateName
from .bk_179 import sortedlbys
from .bk_179 import GetSchoolNameBz
from .bk_179 import GetMajorNameBz
from .bk_179 import unify_keys
from .bk_179 import school_ljdm
from .bk_179 import is_school
from .bk_179 import get_major_name
from .bk_179 import school_names
from .bk_179 import major_names
from .excel数据或mysql操作 import prvadepl
from .excel数据或mysql操作 import optstr
from .excel数据或mysql操作 import MysqlConn
from .excel数据或mysql操作 import read_excel
from .excel数据或mysql操作 import ReadData
from .excel数据或mysql操作 import gen_excel
from .列表操作 import liduel
from .列表操作 import list_dupl
from .字符串类型的判断和提取 import get_chinese
from .字符串类型的判断和提取 import get_letter
from .字符串类型的判断和提取 import get_bletter
from .字符串类型的判断和提取 import get_sletter
from .字符串类型的判断和提取 import get_num
from .字符串类型的判断和提取 import get_num_letter
from .字符串类型的判断和提取 import is_num
from .字符串类型的判断和提取 import is_sletter
from .字符串类型的判断和提取 import is_bletter
from .字符串类型的判断和提取 import is_letter
from .字符串类型的判断和提取 import is_num_letter
from .字符串类型的判断和提取 import is_chinese
from .数据库操作 import PyMySQL
from .文本括号及引号不匹配检查 import 文本括号及引号不匹配检查
from .爬虫辅助功能 import req
from .爬虫辅助功能 import format_string_dict
from .爬虫辅助功能 import webptablesl
from .爬虫辅助功能 import dow_file
from .百度ai接口使用 import TextSimilar
from .百度ai接口使用 import translate
from .百度ai接口使用 import 文本错别字检查
from .省市区名称的提取或判断 import get_ssq
from .省市区名称的提取或判断 import is_ssq

==> txdpy-9.3.3-py3-none-any.whl: txdpy/__init__.py <==
__all__ = ['prurar_code', 'convert_pc', 'convert_kl', 'delete_flase_empty', 'txdavg', 'txdpercavg', 'txdmin', 'txdperc',
           'QueryScoreRank', 'timer', 'exenla', 'getexcelth', 'ExtractEnrollmentLabels', 'UpdateName', 'sortedlbys',
           'GetSchoolNameBz', 'GetMajorNameBz', 'unify_keys', 'school_ljdm', 'prvadepl', 'optstr', 'MysqlConn',
           'read_excel', 'ReadData', 'gen_excel', 'liduel', 'list_dupl', 'get_chinese', 'get_letter', 'get_bletter',
           'get_sletter', 'get_num', 'get_num_letter', 'is_num', 'is_sletter',
           'is_bletter', 'is_letter', 'is_num_letter', 'is_chinese', 'PyMySQL', '文本括号及引号不匹配检查', 'req',
           'format_string_dict', 'webptablesl', 'dow_file', 'TextSimilar', 'translate',
           'get_ssq', 'is_ssq', 'is_school', 'get_major_name', 'school_names', 'major_names','文本模糊搜索','字符串相似度',
           'school_info','XiuzCode','ReadPdf','BkZkMajorInfo','YjsMajorInfo'
           ]

from .bk_179 import prurar_code
from .bk_179 import convert_pc
from .bk_179 import convert_kl
from .bk_179 import delete_flase_empty
from .bk_179 import txdavg
from .bk_179 import txdpercavg
from .bk_179 import txdmin
from .bk_179 import txdperc
from .bk_179 import QueryScoreRank
from .bk_179 import timer
from .bk_179 import exenla
from .bk_179 import getexcelth
from .bk_179 import ExtractEnrollmentLabels
from .bk_179 import UpdateName
from .bk_179 import sortedlbys
from .bk_179 import GetSchoolNameBz
from .bk_179 import GetMajorNameBz
from .bk_179 import unify_keys
from .bk_179 import school_ljdm
from .bk_179 import is_school
from .bk_179 import get_major_name
from .bk_179 import school_names
from .bk_179 import major_names
from .bk_179 import school_info
from .bk_179 import XiuzCode
from .bk_179 import BkZkMajorInfo
from .bk_179 import YjsMajorInfo
from .bk_179 import XiuzCode
from .excel数据或mysql操作 import prvadepl
from .excel数据或mysql操作 import optstr
from .excel数据或mysql操作 import MysqlConn
from .excel数据或mysql操作 import read_excel
from .excel数据或mysql操作 import ReadData
from .excel数据或mysql操作 import gen_excel
from .列表操作 import liduel
from .列表操作 import list_dupl
from .字符串工具 import 字符串相似度
from .字符串工具 import get_chinese
from .字符串工具 import get_letter
from .字符串工具 import get_bletter
from .字符串工具 import get_sletter
from .字符串工具 import get_num
from .字符串工具 import get_num_letter
from .字符串工具 import is_num
from .字符串工具 import is_sletter
from .字符串工具 import is_bletter
from .字符串工具 import is_letter
from .字符串工具 import is_num_letter
from .字符串工具 import is_chinese
from .数据库操作 import PyMySQL
from .文本括号及引号不匹配检查 import 文本括号及引号不匹配检查
from .爬虫辅助功能 import req
from .爬虫辅助功能 import format_string_dict
from .爬虫辅助功能 import webptablesl
from .爬虫辅助功能 import dow_file
from .百度ai接口使用 import TextSimilar
from .百度ai接口使用 import translate
from .百度ai接口使用 import 文本错别字检查
from .省市区名称的提取或判断 import get_ssq
from .省市区名称的提取或判断 import is_ssq
from .文本模糊搜索 import 文本模糊搜索
from .读取pdf import ReadPdf
